@@ -2,14 +2,15 @@ from boto3.dynamodb.conditions import Key
 from boto3.dynamodb.conditions import Attr
 
 from .utils.dynamodb_utils import put_item, delete_item_conditionally
-from .utils.dynamodb_utils import get_item, query_by_key, \
+from .utils.dynamodb_utils import get_item, query_by_key, get_item_and_retrieve_specific_attributes,\
   query_and_project_by_key_condition, scan_table, query_by_key_min_max
 from .utils.dynamodb_utils import update_item, update_item_conditionally
 
+import datetime
 
 ALERTS_TABLE = 'alerts.items'
 ALERTS_CONFIGS_TABLE = 'alerts.config'
-METRICS_TIMESERIES_TABLE = 'metric.ts'
+METRICS_TIMESERIES_TABLE = 'metrics.ts'
 LOGS_METRICS_FETCHING_TABLE = 'logs.cloud_metric_fetching'
 
 ############ ALERTS ###########################
@@ -85,20 +86,17 @@ def terminate_alert(alert_id,start_time, end_timestamp, dynamodb):
 ############ METRICS ##########################
 #create new metric_timeseries item for current day
 def create_metric(metric_id, date_bucket, anom_alarm_id, metric_name, provider, namespace,
-  agent, org_id, app_id, alignment, groupby, first, last, data_points_list, dynamodb):
+  agent, org_id, app_id, alignment, groupby, first, last, dimensions, data_points_list, dynamodb):
   '''
   create_metric(
-    metric_id = 123, date_bucket = "2020-09-10",
+    metric_id = "test1", date_bucket = "2020-10-02",
     anom_alarm_id = "crazy_monkey.juicy_bananas.kiwi_count", metric_name = "error_rate",
-    provider = "aws", namespace = "dynamodb", agent = "CloudWatch", org_id = "Aptoide",
-    app_id = "app1", alignment = "DELTA", groupby = "service", first = 1535530412,
+    provider = "aws", namespace = "dynamodb", agent = "CloudWatch", org_id = "test",
+    app_id = "app1", alignment = "Sum", groupby = "service", first = 1535530412,
+    dimensions = [{"Name": "TableName", "Value": "alerts.config"}],
     last = 1535530432, data_points_list = [
-          { 'val': 50, 'time': 1535530412},
-	        { 'val': 55, 'time' : 1535530415},
-	        { 'val': 56, 'time': 1535530420},
-	        { 'val': 55, 'time' : 1535530430}, 
-	        { 'val': 56, 'time': 1535530432}
-      ]
+      { 'val': 55, 'time' : 1535530430}, 
+      { 'val': 56, 'time': 1535530432}]
   )
   '''
   metric_dict = {
@@ -109,12 +107,13 @@ def create_metric(metric_id, date_bucket, anom_alarm_id, metric_name, provider,
     "provider" : provider,
     "namespace" : namespace,
     "agent" : agent,
-    "org_id" : org_id,
-    "app_id" : app_id, 
-    "alignment" : alignment,
+    "orgId" : org_id,
+    "appId" : app_id, 
+    "metric_alignment" : alignment,
     "groupby" : groupby,
     "first" : first,
     "last": last,
+    "dimensions": dimensions,
     "data_points_list" : data_points_list
   }
 
@@ -122,6 +121,17 @@ def create_metric(metric_id, date_bucket, anom_alarm_id, metric_name, provider,
   response = put_item(metric_dict, METRICS_TIMESERIES_TABLE, dynamodb)
   return response
 
+def get_metric_details(metric_id, dynamodb):
+  now = datetime.datetime.now()
+  date = str(now).split(' ')[0]
+  key_dict = {
+    "metric_id" : metric_id,
+    "date_bucket" : date,
+  }
+  attr_list = ['metric_id', 'metric_name', 'namespace','metric_aligment', 'dimensions']
+  metric_details = get_item_and_retrieve_specific_attributes(key_dict, attr_list, METRICS_TIMESERIES_TABLE, dynamodb)
+  return metric_details
+  
 #query metrics info by metric_id key
 def get_metric_item_by_key(metric_id, curr_date, dynamodb):
   #get_metric_item_by_key(123, '2020-09-10')
