@@ -30,8 +30,8 @@ def get_item(key_dict, table_name, dynamodb):
   '''
   Retrieves item from DynamoDB table
   key_dict = {
-    "prim_key" = "value",
-    "sort_key" = "value"
+    "prim_key" : "value",
+    "sort_key" : "value"
   }
   '''
   table = dynamodb.Table(table_name)
@@ -42,6 +42,23 @@ def get_item(key_dict, table_name, dynamodb):
   else:
     return response['Item']
 
+def get_item_and_retrieve_specific_attributes(key_dict, attr_list, table_name, dynamodb):
+  '''
+  Retrieves item from DynamoDB table and retrieve specific attributes
+  key_dict = {
+    "prim_key" :"value",
+    "sort_key" : "value"
+  }
+  attr_list = ['attr1', 'attr2']
+  '''
+  table = dynamodb.Table(table_name)
+  try:
+    response = table.get_item(Key=key_dict, AttributesToGet=attr_list)
+  except ClientError as e:
+    print(e.response['Error']['Message'])
+  else:
+    return response['Item']
+
 def update_item(key_dict, update_expression, expression_attr_values, table_name, dynamodb):
   '''
   Retrieves item from DynamoDB table
